@@ -23,17 +23,16 @@ import threading
 import unicodedata
 from math import isinf
 
+from zope.event import notify
 from zope.interface import Attribute
-from zope.interface import Invalid
 from zope.interface import Interface
-from zope.interface import providedBy
+from zope.interface import Invalid
 from zope.interface import implementer
+from zope.interface import providedBy
 from zope.interface.interface import InterfaceClass
 from zope.interface.interfaces import IInterface
 from zope.interface.interfaces import IMethod
 
-from zope.event import notify
-
 from zope.schema._bootstrapinterfaces import ConstraintNotSatisfied
 from zope.schema._bootstrapinterfaces import IBeforeObjectAssignedEvent
 from zope.schema._bootstrapinterfaces import IContextAwareDefaultFactory
@@ -41,8 +40,8 @@ from zope.schema._bootstrapinterfaces import IFromBytes
 from zope.schema._bootstrapinterfaces import IFromUnicode
 from zope.schema._bootstrapinterfaces import IValidatable
 from zope.schema._bootstrapinterfaces import NotAContainer
-from zope.schema._bootstrapinterfaces import NotAnIterator
 from zope.schema._bootstrapinterfaces import NotAnInterface
+from zope.schema._bootstrapinterfaces import NotAnIterator
 from zope.schema._bootstrapinterfaces import RequiredMissing
 from zope.schema._bootstrapinterfaces import SchemaNotCorrectlyImplemented
 from zope.schema._bootstrapinterfaces import SchemaNotFullyImplemented
@@ -55,10 +54,6 @@ from zope.schema._bootstrapinterfaces import TooSmall
 from zope.schema._bootstrapinterfaces import ValidationError
 from zope.schema._bootstrapinterfaces import WrongType
 
-from zope.schema._compat import text_type
-from zope.schema._compat import integer_types
-from zope.schema._compat import PY2
-
 
 class _NotGiven(object):
 
@@ -526,7 +521,7 @@ class MinMaxLen(object):
 @implementer(IFromUnicode)
 class Text(MinMaxLen, Field):
     """A field containing text used for human discourse."""
-    _type = text_type
+    _type = str
     unicode_normalization = 'NFC'
 
     def __init__(self,  *args, **kw):
@@ -554,7 +549,7 @@ class Text(MinMaxLen, Field):
         zope.schema._bootstrapinterfaces.ConstraintNotSatisfied:
             (u'foo spam', '')
         """
-        if isinstance(value, text_type):
+        if isinstance(value, str):
             if self.unicode_normalization:
                 value = unicodedata.normalize(
                     self.unicode_normalization, value)
@@ -691,9 +686,9 @@ class Number(Orderable, Field):
         (1+0j)
         >>> f.fromUnicode(u"1/2")
         Fraction(1, 2)
-        >>> f.fromUnicode(str(2**31234) + '.' + str(2**256))
+        >>> f.fromUnicode(str(2**11234) + '.' + str(2**256))
         ... # doctest: +ELLIPSIS
-        Decimal('234...936')
+        Decimal('590...936')
         >>> f.fromUnicode(u"not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
         ...
@@ -711,9 +706,9 @@ class Number(Orderable, Field):
         (1+0j)
         >>> f.fromBytes(b"1/2")
         Fraction(1, 2)
-        >>> f.fromBytes((str(2**31234) + '.' + str(2**256)).encode('ascii'))
+        >>> f.fromBytes((str(2**11234) + '.' + str(2**256)).encode('ascii'))
         ... # doctest: +ELLIPSIS
-        Decimal('234...936')
+        Decimal('590...936')
         >>> f.fromBytes(b"not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
         ...
@@ -761,13 +756,8 @@ class Number(Orderable, Field):
         finally:
             last_exc = None
 
-    # On Python 2, native strings are byte strings, which is
-    # what the converters expect, so we don't need to do any decoding.
-    if PY2:  # pragma: PY2
-        fromBytes = fromUnicode
-    else:    # pragma: PY3
-        def fromBytes(self, value):
-            return self.fromUnicode(value.decode('utf-8'))
+    def fromBytes(self, value):
+        return self.fromUnicode(value.decode('utf-8'))
 
 
 class Complex(Number):
@@ -788,7 +778,7 @@ class Complex(Number):
         (1+0j)
         >>> f.fromUnicode(u"1/2")
         Fraction(1, 2)
-        >>> f.fromUnicode(str(2**31234) + '.' + str(2**256))
+        >>> f.fromUnicode(str(2**11234) + '.' + str(2**256))
         ... # doctest: +ELLIPSIS
         inf
         >>> f.fromUnicode(u"not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
@@ -808,7 +798,7 @@ class Complex(Number):
         (1+0j)
         >>> f.fromBytes(b"1/2")
         Fraction(1, 2)
-        >>> f.fromBytes((str(2**31234) + '.' + str(2**256)).encode('ascii'))
+        >>> f.fromBytes((str(2**11234) + '.' + str(2**256)).encode('ascii'))
         ... # doctest: +ELLIPSIS
         inf
         >>> f.fromBytes(b"not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
@@ -842,7 +832,7 @@ class Real(Complex):
         InvalidNumberLiteral: Invalid literal for Fraction: '1+0j'
         >>> f.fromUnicode("1/2")
         Fraction(1, 2)
-        >>> f.fromUnicode(str(2**31234) + '.' + str(2**256))
+        >>> f.fromUnicode(str(2**11234) + '.' + str(2**256))
         ... # doctest: +ELLIPSIS
         inf
         >>> f.fromUnicode("not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
@@ -876,9 +866,9 @@ class Rational(Real):
         Traceback (most recent call last):
         ...
         InvalidNumberLiteral: Invalid literal for Fraction: '1+0j'
-        >>> f.fromUnicode(str(2**31234) + '.' + str(2**256))
+        >>> f.fromUnicode(str(2**11234) + '.' + str(2**256))
         ... # doctest: +ELLIPSIS
-        Fraction(777..., 330...)
+        Fraction(195..., 330...)
         >>> f.fromUnicode("not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
         ...
@@ -932,7 +922,7 @@ class Int(Integral):
     """A field representing a native integer type. and implementing
     :class:`zope.schema.interfaces.IInt`.
     """
-    _type = integer_types
+    _type = int
     _unicode_converters = (int,)
 
 
@@ -962,9 +952,9 @@ class Decimal(Number):
         Traceback (most recent call last):
         ...
         InvalidDecimalLiteral: Invalid literal for Decimal(): 1/2
-        >>> f.fromUnicode(str(2**31234) + '.' + str(2**256))
+        >>> f.fromUnicode(str(2**11234) + '.' + str(2**256))
         ... # doctest: +ELLIPSIS
-        Decimal('2349...936')
+        Decimal('5901...936')
         >>> f.fromUnicode("not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
         ...
@@ -986,9 +976,9 @@ class Decimal(Number):
         Traceback (most recent call last):
         ...
         InvalidDecimalLiteral: Invalid literal for Decimal(): 1/2
-        >>> f.fromBytes((str(2**31234) + '.' + str(2**256)).encode("ascii"))
+        >>> f.fromBytes((str(2**11234) + '.' + str(2**256)).encode("ascii"))
         ... # doctest: +ELLIPSIS
-        Decimal('2349...936')
+        Decimal('5901...936')
         >>> f.fromBytes(b"not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
         ...
