@@ -20,7 +20,6 @@ from zope.interface import Interface
 from zope.interface.common.mapping import IEnumerableMapping
 from zope.interface.interfaces import IInterface
 
-
 from zope.schema._bootstrapfields import Bool
 from zope.schema._bootstrapfields import Complex
 from zope.schema._bootstrapfields import Decimal
@@ -33,7 +32,6 @@ from zope.schema._bootstrapfields import Rational
 from zope.schema._bootstrapfields import Real
 from zope.schema._bootstrapfields import Text
 from zope.schema._bootstrapfields import TextLine
-
 # Import from _bootstrapinterfaces only because other packages will expect
 # to find these interfaces here.
 from zope.schema._bootstrapinterfaces import ConstraintNotSatisfied
@@ -41,8 +39,8 @@ from zope.schema._bootstrapinterfaces import IBeforeObjectAssignedEvent
 from zope.schema._bootstrapinterfaces import IContextAwareDefaultFactory
 from zope.schema._bootstrapinterfaces import IFromBytes
 from zope.schema._bootstrapinterfaces import IFromUnicode
-from zope.schema._bootstrapinterfaces import IValidatable
 from zope.schema._bootstrapinterfaces import InvalidValue
+from zope.schema._bootstrapinterfaces import IValidatable
 from zope.schema._bootstrapinterfaces import LenOutOfBounds
 from zope.schema._bootstrapinterfaces import NotAContainer
 from zope.schema._bootstrapinterfaces import NotAnInterface
@@ -61,11 +59,9 @@ from zope.schema._bootstrapinterfaces import TooSmall
 from zope.schema._bootstrapinterfaces import ValidationError
 from zope.schema._bootstrapinterfaces import WrongContainedType
 from zope.schema._bootstrapinterfaces import WrongType
-
-from zope.schema._compat import PY3
-
 from zope.schema._messageid import _
 
+
 __all__ = [
     # Exceptions
     'ConstraintNotSatisfied',
@@ -423,7 +419,7 @@ class IText(IMinMaxLen, IIterable, IField):
 
 
 # for things which are of the str type on both Python 2 and 3
-class INativeString(IText if PY3 else IBytes):
+class INativeString(IText):
     """
     A field that always contains the native `str` type.
 
@@ -457,7 +453,7 @@ class ITextLine(IText):
     """Field containing a unicode string without newlines."""
 
 
-class INativeStringLine(ITextLine if PY3 else IBytesLine):
+class INativeStringLine(ITextLine):
     """
     A field that always contains the native `str` type, without any newlines.
 
@@ -616,8 +612,7 @@ class IIntegral(IRational):
 
 class IInt(IIntegral):
     """
-    Field containing exactly the native class :class:`int` (or, on
-    Python 2, ``long``).
+    Field containing exactly the native class :class:`int`.
 
     .. seealso:: :class:`zope.schema.Int`
     """
@@ -921,8 +916,7 @@ class ITokenizedTerm(ITerm):
         "token",
         """Token which can be used to represent the value on a stream.
 
-        The value of this attribute must be a non-empty 7-bit native string
-        (i.e., the ``str`` type on both Python 2 and 3).
+        The value of this attribute must be a non-empty 7-bit ``str``.
         Control characters, including newline, are not allowed.
         """)
 
@@ -1091,7 +1085,7 @@ class IVocabularyFactory(Interface):
     """
 
     def __call__(context):
-        """The *context* provides a location that the vocabulary can make use of.
+        """The *context* provides a location that vocabulary can make use of.
         """
 
 
