@@ -17,11 +17,11 @@ import unittest
 
 from zope.schema.tests.test__bootstrapfields import EqualityTestsMixin
 from zope.schema.tests.test__bootstrapfields import LenTestsMixin
+from zope.schema.tests.test__bootstrapfields import NumberTests
 from zope.schema.tests.test__bootstrapfields import OrderableMissingValueMixin
 from zope.schema.tests.test__bootstrapfields import OrderableTestsMixin
 from zope.schema.tests.test__bootstrapfields import WrongTypeTestsMixin
 
-from zope.schema.tests.test__bootstrapfields import NumberTests
 
 # pylint:disable=protected-access
 # pylint:disable=too-many-lines
@@ -43,8 +43,8 @@ class BytesTests(EqualityTestsMixin,
         return IBytes
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def test_validate_wrong_types(self):
@@ -112,12 +112,11 @@ class ASCIITests(EqualityTestsMixin,
         return IASCII
 
     def test_validate_wrong_types(self):
-        from zope.schema._compat import non_native_string
         field = self._makeOne()
         self.assertAllRaiseWrongType(
             field,
             field._type,
-            non_native_string(''),
+            b'',
             1,
             1.0,
             (),
@@ -160,8 +159,8 @@ class BytesLineTests(EqualityTestsMixin,
         return IBytesLine
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def test_validate_wrong_types(self):
@@ -222,12 +221,11 @@ class ASCIILineTests(EqualityTestsMixin,
         return IASCIILine
 
     def test_validate_wrong_types(self):
-        from zope.schema._compat import non_native_string
         field = self._makeOne()
         self.assertAllRaiseWrongType(
             field,
             field._type,
-            non_native_string(''),
+            b'',
             1,
             1.0,
             (),
@@ -440,6 +438,7 @@ class TimedeltaTests(OrderableMissingValueMixin,
 
     def test_validate_required(self):
         from datetime import timedelta
+
         from zope.schema.interfaces import RequiredMissing
         field = self._makeOne()
         field.validate(timedelta(minutes=15))
@@ -477,6 +476,7 @@ class TimeTests(OrderableMissingValueMixin,
 
     def test_validate_required(self):
         from datetime import time
+
         from zope.schema.interfaces import RequiredMissing
         field = self._makeOne()
         field.validate(time(12, 15, 37))
@@ -585,8 +585,9 @@ class ChoiceTests(EqualityTestsMixin,
 
     def test_bind_w_voc_not_ICSB(self):
         from zope.interface import implementer
-        from zope.schema.interfaces import ISource
+
         from zope.schema.interfaces import IBaseVocabulary
+        from zope.schema.interfaces import ISource
 
         @implementer(IBaseVocabulary)
         @implementer(ISource)
@@ -601,6 +602,7 @@ class ChoiceTests(EqualityTestsMixin,
 
     def test_bind_w_voc_is_ICSB(self):
         from zope.interface import implementer
+
         from zope.schema.interfaces import IContextSourceBinder
         from zope.schema.interfaces import ISource
 
@@ -623,6 +625,7 @@ class ChoiceTests(EqualityTestsMixin,
 
     def test_bind_w_voc_is_ICSB_but_not_ISource(self):
         from zope.interface import implementer
+
         from zope.schema.interfaces import IContextSourceBinder
 
         @implementer(IContextSourceBinder)
@@ -750,6 +753,7 @@ class ChoiceTests(EqualityTestsMixin,
 
     def test__validate_source_is_ICSB_unbound(self):
         from zope.interface import implementer
+
         from zope.schema.interfaces import IContextSourceBinder
 
         @implementer(IContextSourceBinder)
@@ -762,8 +766,9 @@ class ChoiceTests(EqualityTestsMixin,
 
     def test__validate_source_is_ICSB_bound(self):
         from zope.interface import implementer
-        from zope.schema.interfaces import IContextSourceBinder
+
         from zope.schema.interfaces import ConstraintNotSatisfied
+        from zope.schema.interfaces import IContextSourceBinder
         from zope.schema.tests.test_vocabulary import _makeSampleVocabulary
 
         @implementer(IContextSourceBinder)
@@ -795,17 +800,16 @@ class URITests(EqualityTestsMixin,
         return IURI
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def test_validate_wrong_types(self):
-        from zope.schema._compat import non_native_string
         field = self._makeOne()
         self.assertAllRaiseWrongType(
             field,
             field._type,
-            non_native_string(''),
+            b'',
             1,
             1.0,
             (),
@@ -868,8 +872,8 @@ class PythonIdentifierTests(EqualityTestsMixin,
         return PythonIdentifier
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def _getTargetInterface(self):
@@ -917,8 +921,8 @@ class DottedNameTests(EqualityTestsMixin,
         return IDottedName
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def test_ctor_defaults(self):
@@ -941,12 +945,11 @@ class DottedNameTests(EqualityTestsMixin,
         self.assertEqual(dotted.max_dots, 2)
 
     def test_validate_wrong_types(self):
-        from zope.schema._compat import non_native_string
         field = self._makeOne()
         self.assertAllRaiseWrongType(
             field,
             field._type,
-            non_native_string(''),
+            b'',
             1,
             1.0,
             (),
@@ -1042,17 +1045,16 @@ class IdTests(EqualityTestsMixin,
         return IId
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def test_validate_wrong_types(self):
-        from zope.schema._compat import non_native_string
         field = self._makeOne()
         self.assertAllRaiseWrongType(
             field,
             field._type,
-            non_native_string(''),
+            b'',
             1,
             1.0,
             (),
@@ -1127,9 +1129,10 @@ class InterfaceFieldTests(EqualityTestsMixin,
         return IInterfaceField
 
     def test_validate_wrong_types(self):
-        from zope.interface.interfaces import IInterface
         from datetime import date
 
+        from zope.interface.interfaces import IInterface
+
         field = self._makeOne()
         self.assertAllRaiseWrongType(
             field,
@@ -1158,6 +1161,7 @@ class InterfaceFieldTests(EqualityTestsMixin,
 
     def test_validate_required(self):
         from zope.interface import Interface
+
         from zope.schema.interfaces import RequiredMissing
 
         class DummyInterface(Interface):
@@ -1258,9 +1262,9 @@ class CollectionTests(EqualityTestsMixin,
         self.assertEqual(bound.unique, True)
 
     def test__validate_wrong_contained_type(self):
+        from zope.schema._bootstrapfields import Text
         from zope.schema.interfaces import WrongContainedType
         from zope.schema.interfaces import WrongType
-        from zope.schema._bootstrapfields import Text
         text = Text()
         absc = self._makeOne(text)
         with self.assertRaises(WrongContainedType) as exc:
@@ -1275,9 +1279,9 @@ class CollectionTests(EqualityTestsMixin,
         self.assertIs(wct.errors[0].expected_type, text._type)
 
     def test__validate_miss_uniqueness(self):
+        from zope.schema._bootstrapfields import Text
         from zope.schema.interfaces import NotUnique
         from zope.schema.interfaces import WrongType
-        from zope.schema._bootstrapfields import Text
 
         text = Text()
         absc = self._makeOne(text, True)
@@ -1568,9 +1572,9 @@ class MappingTests(EqualityTestsMixin,
         self.assertRaises(RequiredMissing, field.validate, None)
 
     def test_validate_invalid_key_type(self):
+        from zope.schema._bootstrapfields import Int
         from zope.schema.interfaces import WrongContainedType
         from zope.schema.interfaces import WrongType
-        from zope.schema._bootstrapfields import Int
         field = self._makeOne(key_type=Int())
         field.validate({})
         field.validate({1: 'b', 2: 'd'})
@@ -1587,9 +1591,9 @@ class MappingTests(EqualityTestsMixin,
         self.assertIs(field.key_type._type, wct.errors[0].expected_type)
 
     def test_validate_invalid_value_type(self):
+        from zope.schema._bootstrapfields import Int
         from zope.schema.interfaces import WrongContainedType
         from zope.schema.interfaces import WrongType
-        from zope.schema._bootstrapfields import Int
         field = self._makeOne(value_type=Int())
         field.validate({})
         field.validate({'b': 1, 'd': 2})
@@ -1727,8 +1731,8 @@ class NativeStringTests(EqualityTestsMixin,
         return INativeString
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def test_fromBytes(self):
@@ -1756,8 +1760,8 @@ class NativeStringLineTests(EqualityTestsMixin,
         return INativeStringLine
 
     def _getTargetInterfaces(self):
-        from zope.schema.interfaces import IFromUnicode
         from zope.schema.interfaces import IFromBytes
+        from zope.schema.interfaces import IFromUnicode
         return [self._getTargetInterface(), IFromUnicode, IFromBytes]
 
     def test_fromBytes(self):
@@ -1790,6 +1794,7 @@ class StrippedNativeStringLineTests(NativeStringLineTests):
 
 def _makeSampleVocabulary():
     from zope.interface import implementer
+
     from zope.schema.interfaces import IVocabulary
 
     @implementer(IVocabulary)
